@@ -22,10 +22,12 @@
 #endif
 
 #include "swfdec_flv_decoder.h"
+#include "swfdec_audio_decoder.h"
 #include "swfdec_audio_internal.h"
 #include "swfdec_bits.h"
 #include "swfdec_debug.h"
 #include "swfdec_player_internal.h"
+#include "swfdec_video_decoder.h"
 
 enum {
   SWFDEC_STATE_HEADER,			/* need to parse header */
@@ -253,7 +255,7 @@ swfdec_flv_decoder_parse_video_tag (SwfdecFlvDecoder *flv, SwfdecBits *bits, gui
   }
   if (flv->video->len == 0) {
     g_array_append_val (flv->video, tag);
-    swfdec_player_use_video_codec (SWFDEC_DECODER (flv)->player, tag.format);
+    swfdec_decoder_use_video_codec (SWFDEC_DECODER (flv), tag.format);
     return SWFDEC_STATUS_INIT;
   } else if (g_array_index (flv->video, SwfdecFlvVideoTag, 
 	flv->video->len - 1).timestamp < tag.timestamp) {
@@ -292,7 +294,7 @@ swfdec_flv_decoder_parse_audio_tag (SwfdecFlvDecoder *flv, SwfdecBits *bits, gui
   }
   if (flv->audio->len == 0) {
     g_array_append_val (flv->audio, tag);
-    swfdec_player_use_audio_codec (SWFDEC_DECODER (flv)->player, tag.format, tag.original_format);
+    swfdec_decoder_use_audio_codec (SWFDEC_DECODER (flv), tag.format, tag.original_format);
     return SWFDEC_STATUS_INIT;
   } else if (g_array_index (flv->audio, SwfdecFlvAudioTag, 
 	flv->audio->len - 1).timestamp < tag.timestamp) {
