@@ -55,7 +55,6 @@ vivi_wrap_init (ViviWrap *wrap)
 SwfdecAsObject *
 vivi_wrap_object (ViviApplication *app, SwfdecAsObject *object)
 {
-  const char *name;
   SwfdecAsContext *cx;
   SwfdecAsObject *wrap;
   SwfdecAsValue val;
@@ -66,12 +65,7 @@ vivi_wrap_object (ViviApplication *app, SwfdecAsObject *object)
 
   cx = SWFDEC_AS_CONTEXT (app);
   wrap = g_object_new (VIVI_TYPE_WRAP, "context", cx, NULL);
-  /* frames are special */
-  if (SWFDEC_IS_AS_FRAME (object))
-    name = "Frame";
-  else
-    name = "Wrap";
-  swfdec_as_object_get_variable (cx->global, swfdec_as_context_get_string (cx, name), &val);
+  swfdec_as_object_get_variable (cx->global, swfdec_as_context_get_string (cx, "Wrap"), &val);
   if (SWFDEC_AS_VALUE_IS_OBJECT (&val))
     swfdec_as_object_set_constructor (wrap, SWFDEC_AS_VALUE_GET_OBJECT (&val));
   VIVI_WRAP (wrap)->wrap = object;
